==> griptape_nodes-0.29.0.tar.gz: griptape_nodes-0.29.0/docs/ftue/FTUE.md <==
# Lesson Overview

Welcome to your journey with Griptape Nodes! This learning path will guide you through everything from basic setup to creating complex, coordinated workflows with multiple agents.

Each tutorial builds upon the knowledge gained in previous lessons, gradually introducing more complex concepts and techniques.

<div class="grid grid-wide cards" markdown>

- # [Step 1. Getting Started](../ftue/00_tour/FTUE_00_tour.md)

    ![img](00_tour/assets/workspace_interface.png)

    Now that you've [installed](../installation.md) the Griptape Nodes Editor, it's time to launch and work in Griptape Nodes.

    Explore the interface, and understand how to add nodes to your workspace. This simple but foundational tutorial will prepare you for all future workflows.

- # [Step 2: Prompt an Image](../ftue/01_prompt_an_image/FTUE_01_prompt_an_image.md)

    ![img](assets/FTUE_01_prompt_an_image.png)

    Learn how to use the powerful [GenerateImage](../nodes/image/create_image.md) node to transform text descriptions into vivid visual creations.

    This tutorial introduces you to one of the most popular and versatile nodes in the Griptape ecosystem.

- # [Step 3: Coordinating Agents](../ftue/02_coordinating_agents/FTUE_02_coordinating_agents.md)

    ![img](assets/FTUE_02_coordinating_agents.png)

    Discover how to coordinate multiple agents to perform sequential tasks.

    Examine a workflow that translates content between languages, teaching you the fundamentals of agent connections and execution chains. This tutorial introduces the concept of multi-step workflows.

- # [Step 4: Compare Prompts](../ftue/03_compare_prompts/FTUE_03_compare_prompts.md)

    ![img](assets/FTUE_03_compare_prompts.png)

    Take your image generation to the next level by exploring a few different prompting methods.

    Compare basic prompts, GenerateImage "enhanced prompts", and custom agent-enhanced prompts to see how each affects your results. Learn how to craft detailed instructions for more precise creative control.

- # [Step 5: Build a Photography Team](../ftue/04_photography_team/FTUE_04_photography_team.md)

    ![img](assets/FTUE_04_photography_team.png)

    Build an advanced system with specialized agents working together to create spectacular image prompts. Learn about rule sets and tools, and discover how to convert agents into reusable tools for enhanced functionality.

    This advanced tutorial brings together everything you've learned so far.

</div>

## What You'll Learn

By completing this learning path, you'll master:

- Setting up and navigating the Griptape Nodes interface
- Creating and connecting different types of nodes
- Working with AI image generation
- Implementing rule sets and tools for specialized agents
- Converting agents into reusable tools
- Coordinating multiple agents in a single system

Ready to start your journey with Griptape Nodes? Let's learn about the interface in [Getting Started](00_tour/FTUE_00_tour.md)

==> griptape_nodes-0.34.0.tar.gz: griptape_nodes-0.34.0/docs/ftue/FTUE.md <==
# Lesson Overview

Welcome to your journey with Griptape Nodes! This learning path will guide you through everything from basic setup to creating complex, coordinated workflows with multiple agents.

Each tutorial builds upon the knowledge gained in previous lessons, gradually introducing more complex concepts and techniques.

<div class="grid grid-wide cards" markdown>

- # [Lesson 1. Getting Started](../ftue/00_tour/FTUE_00_tour.md)

    ![img](00_tour/assets/workspace_interface.png)

    Now that you've [installed](../installation.md) the Griptape Nodes Editor, it's time to launch and work in Griptape Nodes.

    Explore the interface, and understand how to add nodes to your workspace. This simple but foundational tutorial will prepare you for all future workflows.

- # [Lesson 2: Prompt an Image](../ftue/01_prompt_an_image/FTUE_01_prompt_an_image.md)

    ![img](assets/FTUE_01_prompt_an_image.png)

    Learn how to use the powerful [GenerateImage](../nodes/image/create_image.md) node to transform text descriptions into vivid visual creations.

    This tutorial introduces you to one of the most popular and versatile nodes in the Griptape ecosystem.

- # [Lesson 3: Coordinating Agents](../ftue/02_coordinating_agents/FTUE_02_coordinating_agents.md)

    ![img](assets/FTUE_02_coordinating_agents.png)

    Discover how to coordinate multiple agents to perform sequential tasks.

    Examine a workflow that translates content between languages, teaching you the fundamentals of agent connections and execution chains. This tutorial introduces the concept of multi-step workflows.

- # [Lesson 4: Compare Prompts](../ftue/03_compare_prompts/FTUE_03_compare_prompts.md)

    ![img](assets/FTUE_03_compare_prompts.png)

    Take your image generation to the next level by exploring a few different prompting methods.

    Compare basic prompts, GenerateImage "enhanced prompts", and custom agent-enhanced prompts to see how each affects your results. Learn how to craft detailed instructions for more precise creative control.

- # [Lesson 5: Build a Photography Team](../ftue/04_photography_team/FTUE_04_photography_team.md)

    ![img](assets/FTUE_04_photography_team.png)

    Build an advanced system with specialized agents working together to create spectacular image prompts. Learn about rule sets and tools, and discover how to convert agents into reusable tools for enhanced functionality.

    This advanced tutorial brings together everything you've learned so far.

</div>

## What You'll Learn

By completing this learning path, you'll master:

- Setting up and navigating the Griptape Nodes interface
- Creating and connecting different types of nodes
- Working with AI image generation
- Implementing rule sets and tools for specialized agents
- Converting agents into reusable tools
- Coordinating multiple agents in a single system

Ready to start your journey with Griptape Nodes? Let's learn about the interface in [Lesson 1: Getting Started](00_tour/FTUE_00_tour.md)
